@@ -1,7 +1,8 @@
-package Search::Elasticsearch::Client::5_0::Direct;
-$Search::Elasticsearch::Client::5_0::Direct::VERSION = '5.00';
-use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+package Search::Elasticsearch::Client::6_0::Direct;
+$Search::Elasticsearch::Client::6_0::Direct::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Direct::VERSION = '6.801';use Moo;
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
@@ -15,7 +16,10 @@ has 'indices'  => ( is => 'lazy', init_arg => undef );
 has 'ingest'   => ( is => 'lazy', init_arg => undef );
 has 'snapshot' => ( is => 'lazy', init_arg => undef );
 has 'cat'      => ( is => 'lazy', init_arg => undef );
+has 'ccr'      => ( is => 'lazy', init_arg => undef );
+has 'ilm'      => ( is => 'lazy', init_arg => undef );
 has 'tasks'    => ( is => 'lazy', init_arg => undef );
+has 'xpack'    => ( is => 'lazy', init_arg => undef );
 has 'bulk_helper_class'   => ( is => 'rw' );
 has 'scroll_helper_class' => ( is => 'rw' );
 has '_bulk_class'         => ( is => 'lazy' );
@@ -62,7 +66,10 @@ sub _build_indices  { shift->_build_namespace('Indices') }
 sub _build_ingest   { shift->_build_namespace('Ingest') }
 sub _build_snapshot { shift->_build_namespace('Snapshot') }
 sub _build_cat      { shift->_build_namespace('Cat') }
+sub _build_ccr      { shift->_build_namespace('CCR') }
+sub _build_ilm      { shift->_build_namespace('ILM') }
 sub _build_tasks    { shift->_build_namespace('Tasks') }
+sub _build_xpack    { shift->_build_namespace('XPack') }
 #===================================
 
 __PACKAGE__->_install_api('');
@@ -75,11 +82,11 @@ __PACKAGE__->_install_api('');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct - Thin client with full support for Elasticsearch 5.x APIs
+Search::Elasticsearch::Client::6_0::Direct - Thin client with full support for Elasticsearch 6.x APIs
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -87,7 +94,7 @@ Create a client:
 
     use Search::Elasticsearch;
     my $e = Search::Elasticsearch->new(
-        client => '5_0::Direct'
+        client => '6_0::Direct'
     );
 
 Index a doc:
@@ -166,13 +173,21 @@ Task management:
     say $e->cat->allocation;
     say $e->cat->health;
 
+Cross-cluster replication requests:
+
+    say $e->ccr->follow;
+
+Index lifecycle management requests:
+
+    say $e->ilm->put_lifecycle;
+
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::5_0::Direct> class provides the
-Elasticsearch 5.x compatible client returned by:
+The L<Search::Elasticsearch::Client::6_0::Direct> class provides the
+Elasticsearch 6.x compatible client returned by:
 
     $e = Search::Elasticsearch->new(
-        client => "5_0::Direct"  # default
+        client => "6_0::Direct"  # default
     );
 
 It is intended to be as close as possible to the native REST API that
@@ -187,16 +202,20 @@ and the L<cluster|/cluster()>.
 
 =head1 PREVIOUS VERSIONS OF ELASTICSEARCH
 
-This version of the client supports the Elasticsearch 5.0 branch,
+This version of the client supports the Elasticsearch 6.0 branch,
 which is not backwards compatible with earlier branches.
 
-If you need to talk to a version of Elasticsearch before 5.0.0, please
+If you need to talk to a version of Elasticsearch before 6.0.0, please
 install one of the following modules:
 
 =over
 
 =item *
 
+L<Search::Elasticsearch::Client::5_0>
+
+=item *
+
 L<Search::Elasticsearch::Client::2_0>
 
 =item *
@@ -240,11 +259,11 @@ as top level parameters:
 If you pass in a C<\%params> hash, then it will be included in the
 query string parameters without any error checking. The following:
 
-    $e->search( size => 10, params => { from => 5, size => 5 })
+    $e->search( size => 10, params => { from => 6, size => 6 })
 
 would result in this query string:
 
-    ?from=5&size=10
+    ?from=6&size=10
 
 =head2 Body parameter
 
@@ -261,6 +280,21 @@ UTF-8 bytes and passed as is:
 
     $e->indices->analyze( body => "The quick brown fox");
 
+=head2 Boolean parameters
+
+Elasticsearch 6.0.0 and above no longer accepts truthy and falsey values for booleans.  Instead,
+it will accept only a JSON C<true> or C<false>, or the string equivalents C<"true"> or C<"false">.
+
+In the Perl client, you can use the following values:
+
+=over
+
+=item * True: C<true>, C<\1>, or a L<JSON::PP::Boolean> object.
+
+=item * False: C<false>, C<\0>, or a L<JSON::PP::Boolean> object.
+
+=back
+
 =head2 Filter path parameter
 
 Any API which returns a JSON body accepts a C<filter_path> parameter
@@ -302,12 +336,12 @@ Multiple error codes can be specified with an array:
 =head2 C<bulk_helper_class>
 
 The class to use for the L</bulk_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::5_0::Bulk>.
+L<Search::Elasticsearch::Client::6_0::Bulk>.
 
 =head2 C<scroll_helper_class>
 
 The class to use for the L</scroll_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::5_0::Scroll>.
+L<Search::Elasticsearch::Client::6_0::Scroll>.
 
 =head1 GENERAL METHODS
 
@@ -329,7 +363,7 @@ response, otherwise it throws an error.
 
     $indices_client = $e->indices;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Indices> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Indices> object which can be used
 for managing indices, eg creating, deleting indices, managing mapping,
 index settings etc.
 
@@ -337,28 +371,28 @@ index settings etc.
 
     $ingest_client = $e->ingest;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Ingest> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Ingest> object which can be used
 for managing ingest pipelines.
 
 =head2 C<cluster()>
 
     $cluster_client = $e->cluster;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Cluster> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Cluster> object which can be used
 for managing the cluster, eg cluster-wide settings and cluster health.
 
 =head2 C<nodes()>
 
     $node_client = $e->nodes;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Nodes> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Nodes> object which can be used
 to retrieve node info and stats.
 
 =head2 C<snapshot()>
 
     $snapshot_client = $e->snapshot;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Snapshot> object which
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Snapshot> object which
 is used for managing backup repositories and creating and restoring
 snapshots.
 
@@ -366,17 +400,31 @@ snapshots.
 
     $tasks_client = $e->tasks;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Tasks> object which
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Tasks> object which
 is used for accessing the task management API.
 
 =head2 C<cat()>
 
     $cat_client = $e->cat;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Cat> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Cat> object which can be used
 to retrieve simple to read text info for debugging and monitoring an
 Elasticsearch cluster.
 
+=head2 C<ccr()>
+
+    $ccr_client = $e->ccr;
+
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::CCR> object which can be used
+to handle cross-cluster replication requests.
+
+=head2 C<ilm()>
+
+    $ilm_client = $e->ilm;
+
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::ILM> object which can be used
+to handle index lifecycle management requests.
+
 =head1 DOCUMENT CRUD METHODS
 
 These methods allow you to perform create, index, update and delete requests
@@ -396,14 +444,16 @@ The C<index()> method is used to index a new document or to reindex
 an existing document.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<if_primary_term>,
+    C<if_seq_no>,
     C<op_type>,
     C<parent>,
     C<pipeline>,
     C<refresh>,
     C<routing>,
     C<timeout>,
-    C<timestamp>,
-    C<ttl>,
     C<version>,
     C<version_type>,
     C<wait_for_active_shards>
@@ -427,13 +477,13 @@ C<index>, C<type> and C<id> already exists.
 
 Query string parameters:
     C<consistency>,
+    C<error_trace>,
+    C<human>,
     C<op_type>,
     C<parent>,
     C<refresh>,
     C<routing>,
     C<timeout>,
-    C<timestamp>,
-    C<ttl>,
     C<version>,
     C<version_type>
 
@@ -453,8 +503,10 @@ C<index>, C<type> and C<id>, or will throw a C<Missing> error.
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<preference>,
     C<realtime>,
@@ -482,8 +534,10 @@ plus the document metadata, ie the C<_index>, C<_type> etc.
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<preference>,
     C<realtime>,
@@ -507,11 +561,18 @@ The C<exists()> method returns C<1> if a document with the specified
 C<index>, C<type> and C<id> exists, or an empty string if it doesn't.
 
 Query string parameters:
+    C<_source>,
+    C<_source_excludes>,
+    C<_source_includes>,
+    C<error_trace>,
+    C<human>,
     C<parent>,
     C<preference>,
     C<realtime>,
     C<refresh>,
-    C<routing>
+    C<routing>,
+    C<version>,
+    C<version_type>
 
 See the L<exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-get.html>
 for more information.
@@ -528,6 +589,10 @@ The C<delete()> method will delete the document with the specified
 C<index>, C<type> and C<id>, or will throw a C<Missing> error.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<if_primary_term>,
+    C<if_seq_no>,
     C<parent>,
     C<refresh>,
     C<routing>,
@@ -569,8 +634,8 @@ C<index>, C<type> and C<id> if it exists. Updates can be performed either by:
         ...,
         body => {
             script => {
-                inline => "ctx._source.counter += incr",
-                params => { incr => 5 }
+                source => "ctx._source.counter += incr",
+                params => { incr => 6 }
             }
         }
     );
@@ -583,7 +648,7 @@ C<index>, C<type> and C<id> if it exists. Updates can be performed either by:
             script => {
                 id     => $id,
                 lang   => 'painless',
-                params => { incr => 5 }
+                params => { incr => 6 }
             }
         }
     );
@@ -599,7 +664,7 @@ for more information.
             script => {
                 file   => 'counter',
                 lang   => 'painless',
-                params => { incr => 5 }
+                params => { incr => 6 }
             }
         }
     );
@@ -611,17 +676,19 @@ for more information.
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
+    C<error_trace>,
     C<fields>,
+    C<human>,
+    C<if_primary_term>,
+    C<if_seq_no>,
     C<lang>,
     C<parent>,
     C<refresh>,
     C<retry_on_conflict>,
     C<routing>,
     C<timeout>,
-    C<timestamp>,
-    C<ttl>,
     C<version>,
     C<version_type>,
     C<wait_for_active_shards>
@@ -644,8 +711,10 @@ offsets and payloads for the specified document, assuming that termvectors
 have been enabled.
 
 Query string parameters:
+    C<error_trace>,
     C<field_statistics>,
     C<fields>,
+    C<human>,
     C<offsets>,
     C<parent>,
     C<payloads>,
@@ -675,7 +744,7 @@ that need to be made, bulk requests greatly improve performance.
         body    => [ actions ]          # required
     );
 
-See L<Search::Elasticsearch::Client::5_0::Bulk> and L</bulk_helper()> for a helper module that makes
+See L<Search::Elasticsearch::Client::6_0::Bulk> and L</bulk_helper()> for a helper module that makes
 bulk indexing simpler to use.
 
 The C<bulk()> method can perform multiple L</index()>, L</create()>,
@@ -725,7 +794,7 @@ For instance:
             { title => 'Foo' },
 
             # delete action
-            { delete => { _id => 125 }},
+            { delete => { _id => 126 }},
 
             # update action
             { update => { _id => 126 }},
@@ -738,9 +807,11 @@ cause the others to fail as well.
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
+    C<error_trace>,
     C<fields>,
+    C<human>,
     C<pipeline>,
     C<refresh>,
     C<routing>,
@@ -755,7 +826,7 @@ for more information.
     $bulk_helper = $e->bulk_helper( @args );
 
 Returns a new instance of the class specified in the L</bulk_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::5_0::Bulk>.
+which defaults to L<Search::Elasticsearch::Client::6_0::Bulk>.
 
 =head2 C<mget()>
 
@@ -796,11 +867,14 @@ C<ids> of the documents to retrieve:
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
+    C<error_trace>,
+    C<human>,
     C<preference>,
     C<realtime>,
     C<refresh>,
+    C<routing>,
     C<stored_fields>
 
 See the L<mget docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-get.html>
@@ -828,8 +902,10 @@ Runs multiple L</termvector()> requests in a single request, eg:
     );
 
 Query string parameters:
+    C<error_trace>,
     C<field_statistics>,
     C<fields>,
+    C<human>,
     C<ids>,
     C<offsets>,
     C<parent>,
@@ -889,27 +965,34 @@ L<request body|http://www.elastic.co/guide/en/elasticsearch/reference/current/se
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
     C<allow_no_indices>,
+    C<allow_partial_search_results>,
     C<analyze_wildcard>,
     C<analyzer>,
+    C<batched_reduce_size>,
     C<default_operator>,
     C<df>,
     C<docvalue_fields>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<explain>,
-    C<fielddata_fields>,
     C<from>,
+    C<human>,
+    C<ignore_throttled>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
+    C<max_concurrent_shard_requests>,
+    C<pre_filter_shard_size>,
     C<preference>,
     C<q>,
     C<request_cache>,
+    C<rest_total_hits_as_int>,
     C<routing>,
     C<scroll>,
     C<search_type>,
+    C<seq_no_primary_term>,
     C<size>,
     C<sort>,
     C<stats>,
@@ -921,6 +1004,8 @@ Query string parameters:
     C<terminate_after>,
     C<timeout>,
     C<track_scores>,
+    C<track_total_hits>,
+    C<typed_keys>,
     C<version>
 
 See the L<search reference|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-request-body.html>
@@ -954,14 +1039,18 @@ Query string parameters:
     C<analyzer>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
+    C<ignore_throttled>,
     C<ignore_unavailable>,
     C<lenient>,
     C<lowercase_expanded_terms>
     C<min_score>,
     C<preference>,
     C<q>,
-    C<routing>
+    C<routing>,
+    C<terminate_after>
 
 See the L<count docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-count.html>
 for more information.
@@ -972,7 +1061,7 @@ for more information.
         index   => 'index' | \@indices,     # optional
         type    => 'type'  | \@types,       # optional
 
-        body    => { search params }        # optional
+        body    => { search params }        # required
     );
 
 Perform a search by specifying a template (either predefined or defined
@@ -980,7 +1069,7 @@ within the C<body>) and parameters to use with the template, eg:
 
     $results = $e->search_template(
         body => {
-            inline => {
+            source => {
                 query => {
                     match => {
                         "{{my_field}}" => "{{my_value}}"
@@ -991,7 +1080,7 @@ within the C<body>) and parameters to use with the template, eg:
             params => {
                 my_field => 'foo',
                 my_value => 'bar',
-                my_size  => 5
+                my_size  => 6
             }
         }
     );
@@ -1001,13 +1090,18 @@ for more information.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<explain>,
+    C<human>,
+    C<ignore_throttled>,
     C<ignore_unavailable>,
     C<preference>,
     C<profile>,
+    C<rest_total_hits_as_int>,
     C<scroll>,
-    C<search_type>
+    C<search_type>,
+    C<typed_keys>
 
 =head2 C<render_search_template()>
 
@@ -1020,7 +1114,7 @@ Renders the template, filling in the passed-in parameters and returns the result
 
     $results = $e->render_search_template(
         body => {
-            inline => {
+            source => {
                 query => {
                     match => {
                         "{{my_field}}" => "{{my_value}}"
@@ -1031,7 +1125,7 @@ Renders the template, filling in the passed-in parameters and returns the result
             params => {
                 my_field => 'foo',
                 my_value => 'bar',
-                my_size  => 5
+                my_size  => 6
             }
         }
     );
@@ -1043,7 +1137,9 @@ for more information.
 
     $results = $e->scroll(
         scroll      => '1m',
-        scroll_id   => $id
+        body => {
+            scroll_id   => $id
+        }
     );
 
 When a L</search()> has been performed with the
@@ -1051,10 +1147,13 @@ C<scroll> parameter, the C<scroll()>
 method allows you to keep pulling more results until the results
 are exhausted.
 
-See L</scroll_helper()> and L<Search::Elasticsearch::Client::5_0::Scroll> for a helper utility
+See L</scroll_helper()> and L<Search::Elasticsearch::Client::6_0::Scroll> for a helper utility
 which makes managing scroll requests much easier.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<rest_total_hits_as_int>,
     C<scroll>,
     C<scroll_id>
 
@@ -1065,13 +1164,9 @@ for more information.
 =head2 C<clear_scroll()>
 
     $response = $e->clear_scroll(
-        scroll_id => $id | \@ids    # required
-    );
-
-Or
-
-    $response = $e->clear_scroll(
-        body => $id
+        body => {
+            scroll_id => $id | \@ids    # required
+        }
     );
 
 The C<clear_scroll()> method can clear unfinished scroll requests, freeing
@@ -1082,7 +1177,7 @@ up resources on the server.
     $scroll_helper = $e->scroll_helper( @args );
 
 Returns a new instance of the class specified in the L</scroll_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::5_0::Scroll>.
+which defaults to L<Search::Elasticsearch::Client::6_0::Scroll>.
 
 =head2 C<msearch()>
 
@@ -1114,8 +1209,14 @@ request).  For instance:
     );
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<max_concurrent_searches>,
-    C<search_type>
+    C<max__concurrent_shard_requests>,
+    C<pre_filter_shard_size>,
+    C<rest_total_hits_as_int>,
+    C<search_type>,
+    C<typed_keys>
 
 See the L<msearch docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-multi-search.html>
 for more information.
@@ -1141,18 +1242,23 @@ request).  For instance:
         body => [
             # uses defaults
             {},
-            { inline => { query => { match => { user => "{{user}}" }}} params => { user => 'joe' }},
+            { source => { query => { match => { user => "{{user}}" }}} params => { user => 'joe' }},
 
             # uses a custom index
             { index => 'not_the_default_index' },
-            { inline => { query => { match => { user => "{{user}}" }}} params => { user => 'joe' }},
+            { source => { query => { match => { user => "{{user}}" }}} params => { user => 'joe' }},
         ]
     );
 
 Query string parameters:
-    C<search_type>
+    C<error_trace>,
+    C<human>,
+    C<max_concurrent_searches>,
+    C<rest_total_hits_as_int>,
+    C<search_type>,
+    C<typed_keys>
 
-See the L<msearch-template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/multi-search-template.html>
+See the L<msearch-template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-multi-search.html>
 for more information.
 
 =head2 C<explain()>
@@ -1182,14 +1288,15 @@ For instance:
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
     C<analyze_wildcard>,
     C<analyzer>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
+    C<human>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
     C<parent>,
     C<preference>,
     C<q>,
@@ -1199,33 +1306,30 @@ Query string parameters:
 See the L<explain docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-explain.html>
 for more information.
 
-=head2 C<field_stats()>
+=head2 C<field_caps()>
 
-    $response = $e->field_stats(
+    $response = $e->field_caps(
         index   => 'index'   | \@indices,   # optional
-        fields  => 'field'   | \@fields,    # optional
-        level   => 'cluster' | 'indices',   # optional
         body    => { filters }              # optional
     );
 
-The C<field-stats> API returns statistical properties of a field
-(such as min and max values) without executing a search.
+The C<field-caps> API returns field types and abilities, merged across indices.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<fields>,
-    C<ignore_unavailable>,
-    C<level>
+    C<human>,
+    C<ignore_unavailable>
 
-See the L<field-stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-field-stats.html>
+See the L<field-caps docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-field-caps.html>
 for more information.
 
 =head2 C<search_shards()>
 
     $response = $e->search_shards(
         index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
     )
 
 The C<search_shards()> method returns information about which shards on
@@ -1233,7 +1337,9 @@ which nodes will execute a search request.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<error_trace>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
     C<local>,
     C<preference>,
@@ -1242,6 +1348,27 @@ Query string parameters:
 See the L<search-shards docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-shards.html>
 for more information.
 
+=head2 C<rank_eval()>
+
+    $result = $e->rank_eval(
+        index   => 'index' | \@indices,     # optional
+        body    => {...}                    # required
+    );
+
+The ranking evaluation API provides a way to execute test cases to determine whether search results
+are improving or worsening.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<error_trace>,
+    C<expand_wildcards>,
+    C<filter_path>,
+    C<human>,
+    C<ignore_unavailable>
+
+See the L<rank-eval docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/search-rank-eval.html>
+for more information.
+
 =head1 CRUD-BY-QUERY METHODS
 
 =head2 C<delete_by_query()>
@@ -1256,19 +1383,20 @@ The C<delete_by_query()> method deletes all documents which match the specified
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
     C<allow_no_indices>,
     C<analyze_wildcard>,
     C<analyzer>,
     C<conflicts>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<from>,
+    C<human>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
     C<preference>,
     C<q>,
     C<refresh>,
@@ -1280,6 +1408,7 @@ Query string parameters:
     C<search_timeout>,
     C<search_type>,
     C<size>,
+    C<slices>,
     C<sort>,
     C<stats>,
     C<terminate_after>,
@@ -1291,6 +1420,25 @@ Query string parameters:
 See the L<delete-by-query docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete-by-query.html>
 for more information.
 
+=head2 C<delete_by_query_rethrottle()>
+
+    $response = $e->delete_by_query_rethrottle(
+        task_id             => 'id'         # required
+        requests_per_second => num
+    );
+
+The C<delete_by_query_rethrottle()> API is used to dynamically update the throtting
+of an existing delete-by-query request, identified by C<task_id>.
+
+Query string parameters:
+    C<error_trace>,
+    C<filter_path>,
+    C<human>,
+    C<requests_per_second>
+
+See the L<delete-by-query-rethrottle docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-delete-by-query.html>
+for more information.
+
 =head2 C<reindex()>
 
     $response = $e->reindex(
@@ -1301,8 +1449,11 @@ The C<reindex()> API is used to index documents from one index or multiple indic
 to a new index.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<refresh>,
     C<requests_per_second>,
+    C<slices>,
     C<timeout>,
     C<wait_for_active_shards>,
     C<wait_for_completion>
@@ -1310,6 +1461,25 @@ Query string parameters:
 See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
 for more information.
 
+=head2 C<reindex_rethrottle()>
+
+    $response = $e->delete_by_query_rethrottle(
+        task_id => 'id',            # required
+        requests_per_second => num
+    );
+
+The C<reindex_rethrottle()> API is used to dynamically update the throtting
+of an existing reindex request, identified by C<task_id>.
+
+Query string parameters:
+    C<error_trace>,
+    C<filter_path>,
+    C<human>,
+    C<requests_per_second>
+
+See the L<reindex-rethrottle docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
+for more information.
+
 =head2 C<update_by_query()>
 
     $response = $e->update_by_query(
@@ -1323,19 +1493,20 @@ multiple indices using a script.
 
 Query string parameters:
     C<_source>,
-    C<_source_exclude>,
-    C<_source_include>,
+    C<_source_excludes>,
+    C<_source_includes>,
     C<allow_no_indices>,
     C<analyze_wildcard>,
     C<analyzer>,
     C<conflicts>,
     C<default_operator>,
     C<df>,
+    C<error_trace>,
     C<expand_wildcards>,
     C<from>,
+    C<human>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
     C<pipeline>,
     C<preference>,
     C<q>,
@@ -1348,6 +1519,7 @@ Query string parameters:
     C<search_timeout>,
     C<search_type>,
     C<size>,
+    C<slices>,
     C<sort>,
     C<stats>,
     C<terminate_after>,
@@ -1360,178 +1532,25 @@ Query string parameters:
 See the L<update_by_query docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update-by-query.html>
 for more information.
 
-=head2 C<reindex_rethrottle>
+=head2 C<update_by_query_rethrottle()>
 
-    $response = $e->reindex_rethrottle(
-        task_id             => 'task_id',       # required
-        requests_per_second => $req_per_second
+    $response = $e->update_by_query_rethrottle(
+        task_id             => 'id'         # required
+        requests_per_second => num
     );
 
-The C<reindex_rethrottle()> API is used to dynamically update the throtting
-of an existing reindex request, identified by C<task_id>.
+The C<update_by_query_rethrottle()> API is used to dynamically update the throtting
+of an existing update-by-query request, identified by C<task_id>.
 
 Query string parameters:
+    C<error_trace>,
+    C<filter_path>,
+    C<human>,
     C<requests_per_second>
 
-See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
+See the L<update-by-query-rethrottle docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-update-by-query.html>
 for more information.
 
-=head1 PERCOLATION METHODS
-
-=head2 C<percolate()>
-
-    $results = $e->percolate(
-        index   => 'my_index',      # required
-        type    => 'my_type',       # required
-
-        body    => { percolation }  # required
-    );
-
-Percolation is search inverted: instead of finding docs which match a
-particular query, it finds queries which match a particular document, eg
-for I<alert-me-when> functionality.
-
-The C<percolate()> method runs a percolation request to find the
-queries matching a particular document. In the C<body> you should pass the
-C<_source> field of the document under the C<doc> key:
-
-    $results = $e->percolate(
-        index   => 'my_index',
-        type    => 'my_type',
-        body    => {
-            doc => {
-                title => 'Elasticsearch rocks'
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<percolate_format>,
-    C<percolate_index>,
-    C<percolate_preference>,
-    C<percolate_routing>,
-    C<percolate_type>,
-    C<preference>,
-    C<routing>,
-    C<version>,
-    C<version_type>
-
-See the L<percolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
-for more information.
-
-=head2 C<count_percolate()>
-
-    $results = $e->count_percolate(
-        index   => 'my_index',      # required
-        type    => 'my_type',       # required
-
-        body    => { percolation }  # required
-    );
-
-The L</count_percolate()> request works just like the L</percolate()>
-request except that it returns a count of all matching queries, instead
-of the queries themselves.
-
-    $results = $e->count_percolate(
-        index   => 'my_index',
-        type    => 'my_type',
-        body    => {
-            doc => {
-                title => 'Elasticsearch rocks'
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<percolate_index>,
-    C<percolate_type>,
-    C<preference>,
-    C<routing>,
-    C<version>,
-    C<version_type>
-
-See the L<percolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
-for more information.
-
-=head2 C<mpercolate()>
-
-    $results = $e->mpercolate(
-        index   => 'my_index',               # required if type
-        type    => 'my_type',                # optional
-
-        body    => [ percolation requests ]  # required
-    );
-
-Multi-percolation allows multiple L</percolate()> requests to be run
-in a single request.
-
-    $results = $e->mpercolate(
-        index   => 'my_index',
-        type    => 'my_type',
-        body    => [
-            # first request
-            { percolate => {
-                index => 'twitter',
-                type  => 'tweet'
-            }},
-            { doc => {message => 'some_text' }},
-
-            # second request
-            { percolate => {
-                index => 'twitter',
-                type  => 'tweet',
-                id    => 1
-            }},
-            {},
-        ]
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>
-
-See the L<mpercolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
-for more information.
-
-=head2 C<suggest()>
-
-    $results = $e->suggest(
-        index   => 'index' | \@indices,     # optional
-
-        body    => { suggest request }      # required
-    );
-
-The C<suggest()> method is used to run
-L<did-you-mean|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-suggesteres-phrase.html>
-or L<search-as-you-type|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-suggesters-completion.html>
-suggestion requests, which can also be run as part of a L</search()> request.
-
-    $results = $e->suggest(
-        index   => 'my_index',
-        body    => {
-            my_suggestions => {
-                phrase  => {
-                    text    => 'johnny walker',
-                    field   => 'title'
-                }
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<preference>,
-    C<routing>
-
 =head1 INDEXED SCRIPT METHODS
 
 Elasticsearch allows you to store scripts in the cluster state
@@ -1540,115 +1559,82 @@ and reference them by id. The methods to manage indexed scripts are as follows:
 =head2 C<put_script()>
 
     $result  = $e->put_script(
-        lang => 'lang',     # required
-        id   => 'id',       # required
-        body => { script }  # required
+        id      => 'id',       # required
+        context => $context,   # optional
+        body    => { script }  # required
     );
 
 The C<put_script()> method is used to store a script in the cluster state. For instance:
 
     $result  = $e->put_scripts(
-        lang => 'painless',
         id   => 'hello_world',
         body => {
-          script => q(return "hello world");
+          script => {
+            lang   => 'painless',
+            source => q(return "hello world")
+          }
         }
     );
 
-Query string parameters: None
+Query string parameters:
+    C<error_trace>,
+    C<human>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
 =head2 C<get_script()>
 
     $script = $e->get_script(
-        lang => 'lang',     # required
         id   => 'id',       # required
     );
 
 Retrieve the indexed script from the cluster state.
 
-Query string parameters: None
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<master_timeout>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
 =head2 C<delete_script()>
 
     $script = $e->delete_script(
-        lang => 'lang',     # required
         id   => 'id',       # required
     );
 
 Delete the indexed script from the cluster state.
 
-Query string parameters: None
+Query string parameters:
+    C<error_trace>,
+    C<human>,
+    C<master_timeout>,
+    C<timeout>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
-=head1 INDEXED SEARCH TEMPLATE METHODS
+=head2 C<scripts_painless_execute()>
 
-Mustache templates can be used to create search requests.  These templates can
-be stored in the cluster state and retrieved by ID. The methods to
-manage indexed scripts are as follows:
-
-=head2 C<put_template()>
-
-    $result  = $e->put_template(
-        id   => 'id',                       # required
-        body => { template } || "template"  # required
+    $result = $e->scripts_painless_execute(
+        body => {...}   # required
     );
 
-The C<put_template()> method is used to store a template in the cluster state.
-For instance:
+The Painless execute API allows an arbitrary script to be executed and a result to be returned.
 
-    $result  = $e->put_template(
-        id   => 'hello_world',
-        body => {
-          template => {
-            query => {
-              match => {
-                title => "hello world"
-              }
-            }
-          }
-      }
-    );
+Query string parameters:
+    C<error_trace>,
+    C<filter_path>,
+    C<human>
 
-Query string parameters: None
-
-See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
-
-=head2 C<get_template()>
-
-    $script = $e->get_template(
-        id   => 'id',       # required
-    );
-
-Retrieve the indexed template from the cluster state.
-
-Query string parameters: None
-
-See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
-
-=head2 C<delete_template()>
-
-    $script = $e->delete_template(
-        id   => 'id',       # required
-    );
-
-Delete the indexed template from the cluster state.
-
-Query string parameters: None
-
-See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
+See the L<painless execution docs|https://www.elastic.co/guide/en/elasticsearch/painless/current/painless-execute-api.html> for more.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
@@ -1658,5 +1644,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 5.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 6.x APIs
 
