@@ -1,7 +1,8 @@
-package Search::Elasticsearch::Client::5_0::Direct::Tasks;
-$Search::Elasticsearch::Client::5_0::Direct::Tasks::VERSION = '5.00';
-use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+package Search::Elasticsearch::Client::6_0::Direct::Tasks;
+$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.801';use Moo;
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('tasks');
 
@@ -13,11 +14,11 @@ __PACKAGE__->_install_api('tasks');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Tasks - A client for accessing the Task Management API
+Search::Elasticsearch::Client::6_0::Direct::Tasks - A client for accessing the Task Management API
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -40,10 +41,12 @@ about that task.
 Query string parameters:
     C<actions>,
     C<detailed>,
+    C<error_trace>,
     C<group_by>,
-    C<node_id>,
-    C<parent_node>,
-    C<parent_task>,
+    C<human>,
+    C<nodes>,
+    C<parent_task_id>,
+    C<timeout>,
     C<wait_for_completion>
 
 See the L<task management docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/tasks.html>
@@ -58,6 +61,8 @@ for more information.
 The C<get()> method returns the task with the specified ID.
 
 Query string parameters:
+    C<error_trace>,
+    C<human>,
     C<wait_for_completion>
 
 See the L<task management docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/tasks.html>
@@ -66,27 +71,29 @@ for more information.
 =head2 C<cancel()>
 
     $response = $e->tasks->cancel(
-        task_id => $task_id  # option
+        task_id => $task_id  # required
     );
 
 The C<cancel()> method attempts to cancel the specified C<task_id> or multiple tasks.
 
 Query string parameters:
     C<actions>,
-    C<node_id>,
-    C<parent_node>,
-    C<parent_task>
+    C<error_trace>,
+    C<human>,
+    C<nodes>,
+    C<parent_task_id>,
+    C<timeout>
 
 See the L<task management docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/tasks.html>
 for more information.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
