@@ -1,6 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Role::Bulk;
-$Search::Elasticsearch::Client::5_0::Role::Bulk::VERSION = '5.00';
-use Moo::Role;
+package Search::Elasticsearch::Client::6_0::Role::Bulk;
+$Search::Elasticsearch::Client::6_0::Role::Bulk::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Role::Bulk::VERSION = '6.801';use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -33,16 +34,6 @@ our %Actions = (
     'delete' => 1
 );
 
-around BUILDARGS => sub {
-    my $orig = shift;
-    my ( $class, $params ) = parse_params(@_);
-    my $es = $params->{es} or throw( 'Param', 'Missing required param <es>' );
-    $params->{_metadata_params} = $es->api('bulk.metadata')->{params};
-    $params->{_update_params}   = $es->api('bulk.update')->{params};
-    $params->{_required_params} = $es->api('bulk.required')->{params};
-    return $class->$orig($params);
-};
-
 #===================================
 sub _build__serializer { shift->es->transport->serializer }
 #===================================
@@ -62,10 +53,14 @@ sub _build_on_error {
 sub BUILDARGS {
 #===================================
     my ( $class, $params ) = parse_params(@_);
+    my $es = $params->{es} or throw( 'Param', 'Missing required param <es>' );
+    $params->{_metadata_params} = $es->api('bulk.metadata')->{params};
+    $params->{_update_params}   = $es->api('bulk.update')->{params};
+    $params->{_required_params} = $es->api('bulk.required')->{params};
+    my $bulk_spec = $es->api('bulk');
     my %args;
-    for (qw(index type consistency fields refresh replication routing timeout))
-    {
-        $args{$_} = $params->{$_}
+    for ( keys %{ $bulk_spec->{qs} }, keys %{ $bulk_spec->{parts} } ) {
+        $args{$_} = delete $params->{$_}
             if exists $params->{$_};
     }
     $params->{_bulk_args} = \%args;
@@ -100,7 +95,7 @@ sub update {
 sub create_docs {
 #===================================
     my $self = shift;
-    $self->add_action( map { ( 'create' => { _source => $_ } ) } @_ );
+    $self->add_action( map { ( 'create' => { source => $_ } ) } @_ );
 }
 
 #===================================
@@ -127,12 +122,10 @@ sub _encode_action {
     my $params     = {%$orig};
     my $serializer = $self->_serializer;
 
-    for ( @{ $self->_metadata_params } ) {
-        my $val
-            = exists $params->{$_}    ? delete $params->{$_}
-            : exists $params->{"_$_"} ? delete $params->{"_$_"}
-            :                           next;
-        $metadata{"_$_"} = $val;
+    my $meta_params = $self->_metadata_params;
+    for ( keys %$meta_params ) {
+        next unless exists $params->{$_};
+        $metadata{ $meta_params->{$_} } = delete $params->{$_};
     }
 
     for ( @{ $self->_required_params } ) {
@@ -148,14 +141,10 @@ sub _encode_action {
         }
     }
     elsif ( $action ne 'delete' ) {
-        $source
-            = delete $params->{_source}
-            || delete $params->{source}
-            || throw(
-            'Param',
+        $source = delete $params->{source}
+            || throw( 'Param',
             "Missing <source> for action <$action>: "
-                . $serializer->encode($orig)
-            );
+                . $serializer->encode($orig) );
     }
 
     throw(    "Unknown params <"
@@ -272,7 +261,7 @@ sub _doc_transformer {
 
 1;
 
-# ABSTRACT: Provides common functionality to L<Elasticseach::Client::5_0::Bulk> and L<Search::Elasticsearch::Client::5_0::Async::Bulk>
+# ABSTRACT: Provides common functionality to L<Elasticseach::Client::6_0::Bulk> and L<Search::Elasticsearch::Client::6_0::Async::Bulk>
 
 __END__
 
@@ -282,19 +271,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Role::Bulk - Provides common functionality to L<Elasticseach::Client::5_0::Bulk> and L<Search::Elasticsearch::Client::5_0::Async::Bulk>
+Search::Elasticsearch::Client::6_0::Role::Bulk - Provides common functionality to L<Elasticseach::Client::6_0::Bulk> and L<Search::Elasticsearch::Client::6_0::Async::Bulk>
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
