@@ -1,11 +1,11 @@
-package Search::Elasticsearch::Client::5_0::Role::Scroll;
-$Search::Elasticsearch::Client::5_0::Role::Scroll::VERSION = '5.00';
-use Moo::Role;
+package Search::Elasticsearch::Client::6_0::Role::Scroll;
+$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::6_0::Role::Scroll::VERSION = '6.801';use Moo::Role;
 requires 'finish';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Devel::GlobalDestruction;
 use namespace::clean;
-
 has 'es' => ( is => 'ro', required => 1 );
 has 'scroll'        => ( is => 'ro' );
 has 'scroll_in_qs'  => ( is => 'ro' );
@@ -35,7 +35,7 @@ sub scroll_request {
         $args{scroll_id} = $self->_scroll_id;
     }
     else {
-        $args{body} = $self->_scroll_id;
+        $args{body} = { scroll_id => $self->_scroll_id };
     }
     $self->es->scroll(%args);
 }
@@ -50,7 +50,7 @@ sub DEMOLISH {
 
 1;
 
-# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::5_0::Scroll> and L<Search::Elasticsearch::Client::5_0::Async::Scroll>
+# ABSTRACT: Provides common functionality to L<Search::Elasticsearch::Client::6_0::Scroll> and L<Search::Elasticsearch::Client::6_0::Async::Scroll>
 
 __END__
 
@@ -60,19 +60,19 @@ __END__
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::5_0::Scroll> and L<Search::Elasticsearch::Client::5_0::Async::Scroll>
+Search::Elasticsearch::Client::6_0::Role::Scroll - Provides common functionality to L<Search::Elasticsearch::Client::6_0::Scroll> and L<Search::Elasticsearch::Client::6_0::Async::Scroll>
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
