@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Cxn::LWP;
-$Search::Elasticsearch::Cxn::LWP::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::Cxn::LWP::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Cxn::LWP::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
 use LWP::UserAgent();
@@ -97,7 +98,7 @@ Search::Elasticsearch::Cxn::LWP - A Cxn implementation which uses LWP
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -271,11 +272,11 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
