@@ -1,6 +1,7 @@
 package Search::Elasticsearch::CxnPool::Sniff;
-$Search::Elasticsearch::CxnPool::Sniff::VERSION = '5.00';
-use Moo;
+$Search::Elasticsearch::CxnPool::Sniff::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::CxnPool::Sniff::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Sniff',
     'Search::Elasticsearch::Role::Is_Sync';
 
@@ -81,7 +82,7 @@ Search::Elasticsearch::CxnPool::Sniff - A CxnPool for connecting to a local clus
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -239,11 +240,11 @@ From L<Search::Elasticsearch::Role::CxnPool>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
