@@ -1,6 +1,7 @@
 package Search::Elasticsearch::CxnPool::Static::NoPing;
-$Search::Elasticsearch::CxnPool::Static::NoPing::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::CxnPool::Static::NoPing::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::CxnPool::Static::NoPing::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static::NoPing',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(throw);
@@ -18,7 +19,7 @@ Search::Elasticsearch::CxnPool::Static::NoPing - A CxnPool for connecting to a r
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -161,11 +162,11 @@ From L<Search::Elasticsearch::Role::CxnPool>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
