@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '5.00';
-our $DEBUG = 0;
+$Search::Elasticsearch::Error::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Error::VERSION = '6.801';our $DEBUG = 0;
 
 @Search::Elasticsearch::Error::Internal::ISA     = __PACKAGE__;
 @Search::Elasticsearch::Error::Param::ISA        = __PACKAGE__;
@@ -179,7 +180,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -246,7 +247,7 @@ L<max_content_length|Search::Elasticsearch::Role::Cxn/max_content_length>.
 
 The request took longer than the specified C<timeout>.  Currently only
 applies to the
-L<cluster_health|Search::Elasticsearch::Client::5_0::Direct::Cluster/cluster_health()>
+L<cluster_health|Search::Elasticsearch::Client::6_0::Direct::Cluster/cluster_health()>
 request.
 
 =back
@@ -312,11 +313,11 @@ this module.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
