@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Client;
-$Search::Elasticsearch::Role::Client::VERSION = '5.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::Client::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Role::Client::VERSION = '6.801';use Moo::Role;
 use namespace::clean;
 
 requires 'parse_request';
@@ -28,7 +29,7 @@ Search::Elasticsearch::Role::Client - Provides common functionality for Client i
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -46,11 +47,11 @@ to L<Search::Elasticsearch::Transport/perform_request()>.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
