@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Client::Direct;
-$Search::Elasticsearch::Role::Client::Direct::VERSION = '5.02';
-use Moo::Role;
+$Search::Elasticsearch::Role::Client::Direct::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Role::Client::Direct::VERSION = '6.801';use Moo::Role;
 with 'Search::Elasticsearch::Role::Client';
 use Search::Elasticsearch::Util qw(load_plugin is_compat throw);
 
@@ -30,11 +31,7 @@ sub parse_request {
     catch {
         chomp $_;
         my $name = $defn->{name} || '<unknown method>';
-        $self->logger->throw_error( 'Param',
-                  "$_ in ($name) request. "
-                . "See docs at: http://www.elastic.co/guide/en/elasticsearch/reference/current/"
-                . $defn->{doc}
-                . '.html' );
+        $self->logger->throw_error( 'Param', "$_ in ($name) request. " );
     };
     return $request;
 }
@@ -179,7 +176,7 @@ Search::Elasticsearch::Role::Client::Direct - Request parsing for Direct clients
 
 =head1 VERSION
 
-version 5.02
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -226,11 +223,11 @@ not yet supported by the released client.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
