@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '6.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::Cxn::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Role::Cxn::VERSION = '6.801';use Moo::Role;
 use Search::Elasticsearch::Util qw(parse_params throw to_list);
 use List::Util qw(min);
 use Try::Tiny;
@@ -11,6 +12,7 @@ use IO::Compress::Gzip();
 use IO::Uncompress::Gunzip qw(gunzip $GunzipError);
 use Search::Elasticsearch::Util qw(to_list);
 use namespace::clean;
+use Net::IP;
 
 requires qw(perform_request error_from_text handle);
 
@@ -57,6 +59,12 @@ my %Code_To_Error = (
 sub stringify { shift->uri . '' }
 #===================================
 
+#===================================
+sub get_user_agent {
+#===================================
+    return sprintf("elasticsearch-perl/%s- (PERL %s)", $Search::Elasticsearch::VERSION, $]);
+}
+
 #===================================
 sub BUILDARGS {
 #===================================
@@ -66,10 +74,11 @@ sub BUILDARGS {
         || { host => 'localhost', port => '9200' };
 
     unless ( ref $node eq 'HASH' ) {
+        $node = "[$node]" if Net::IP::ip_is_ipv6($node);
         unless ( $node =~ m{^http(s)?://} ) {
             $node = ( $params->{use_https} ? 'https://' : 'http://' ) . $node;
         }
-        if ( $params->{port} && $node !~ m{//[^/]+:\d+} ) {
+        if ( $params->{port} && $node !~ m{//[^/\[]+:\d+} ) {
             $node =~ s{(//[^/]+)}{$1:$params->{port}};
         }
         my $uri = URI->new($node);
@@ -98,7 +107,7 @@ sub BUILDARGS {
 
     if ($userinfo) {
         require MIME::Base64;
-        my $auth = MIME::Base64::encode_base64($userinfo);
+        my $auth = MIME::Base64::encode_base64( $userinfo, "" );
         chomp $auth;
         $default_headers{Authorization} = "Basic $auth";
     }
@@ -111,17 +120,19 @@ sub BUILDARGS {
         $default_headers{'Accept-Encoding'} = "deflate";
     }
 
-    $params->{scheme}          = $scheme;
-    $params->{is_https}        = $scheme eq 'https';
-    $params->{host}            = $host;
-    $params->{port}            = $port;
-    $params->{path}            = $path;
-    $params->{userinfo}        = $userinfo;
+    $default_headers{'User-Agent'} = $class->get_user_agent();
+
+    $params->{scheme}   = $scheme;
+    $params->{is_https} = $scheme eq 'https';
+    $params->{host}     = $host;
+    $params->{port}     = $port;
+    $params->{path}     = $path;
+    $params->{userinfo} = $userinfo;
+    $host = "[$host]" if Net::IP::ip_is_ipv6($host);
     $params->{uri}             = URI->new("$scheme://$host:$port$path");
     $params->{default_headers} = \%default_headers;
 
     return $params;
-
 }
 
 #===================================
@@ -305,7 +316,7 @@ sub process_response {
     # Deprecation warnings
     if ( my $warnings = $headers->{warning} ) {
         my $warning_string = _parse_warnings($warnings);
-        my %temp = (%$params);
+        my %temp           = (%$params);
         delete $temp{data};
         $self->logger->deprecation( $warning_string, \%temp );
     }
@@ -365,8 +376,7 @@ sub _parse_warnings {
     for (@warnings) {
         if ( $_ =~ /^\d+\s+\S+\s+"((?:\\"|[^"])+)"/ ) {
             my $msg = $1;
-            $msg=~s/\\"/"/g,
-            push @str, $msg;
+            $msg =~ s/\\"/"/g, push @str, $msg;
         }
         else {
             push @str, $_;
@@ -420,7 +430,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to HTTP Cxn imp
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -784,11 +794,11 @@ Elasticsearch.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
