@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Serializer;
-$Search::Elasticsearch::Role::Serializer::VERSION = '5.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::Serializer::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Role::Serializer::VERSION = '6.801';use Moo::Role;
 
 requires qw(encode decode encode_pretty encode_bulk mime_type);
 
@@ -20,7 +21,7 @@ Search::Elasticsearch::Role::Serializer - An interface for Serializer modules
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -55,11 +56,11 @@ See L<Search::Elasticsearch::Serializer::JSON> for more.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
