@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Transport;
-$Search::Elasticsearch::Role::Transport::VERSION = '5.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::Transport::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Role::Transport::VERSION = '6.801';use Moo::Role;
 
 requires qw(perform_request);
 
@@ -72,15 +73,15 @@ Search::Elasticsearch::Role::Transport - Transport role providing interface betw
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
