@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Serializer::JSON::Cpanel;
-$Search::Elasticsearch::Serializer::JSON::Cpanel::VERSION = '5.00';
-use Cpanel::JSON::XS;
+$Search::Elasticsearch::Serializer::JSON::Cpanel::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Serializer::JSON::Cpanel::VERSION = '6.801';use Cpanel::JSON::XS;
 use Moo;
 
 has 'JSON' =>
@@ -20,7 +21,7 @@ Search::Elasticsearch::Serializer::JSON::Cpanel - A JSON Serializer using Cpanel
 
 =head1 VERSION
 
-version 5.00
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -50,11 +51,11 @@ This class does L<Search::Elasticsearch::Role::Serializer::JSON>.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
