@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Serializer::JSON::XS;
-$Search::Elasticsearch::Serializer::JSON::XS::VERSION = '5.02';
-use Moo;
+$Search::Elasticsearch::Serializer::JSON::XS::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Serializer::JSON::XS::VERSION = '6.801';use Moo;
 use JSON::XS 2.26;
 
 has 'JSON' => ( is => 'ro', default => sub { JSON::XS->new->utf8(1) } );
@@ -19,7 +20,7 @@ Search::Elasticsearch::Serializer::JSON::XS - A JSON Serializer using JSON::XS
 
 =head1 VERSION
 
-version 5.02
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -49,11 +50,11 @@ This class does L<Search::Elasticsearch::Role::Serializer::JSON>.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
