@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Util;
-$Search::Elasticsearch::Util::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::Util::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Util::VERSION = '6.801';use Moo;
 use Search::Elasticsearch::Error();
 use Scalar::Util qw(blessed);
 use Module::Runtime qw(compose_module_name is_module_name use_module);
@@ -119,15 +120,15 @@ Search::Elasticsearch::Util - A utility class for internal use by Search::Elasti
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
